@@ -11,7 +11,7 @@ use Raisin::Response;
 use Raisin::Routes;
 use Raisin::Util;
 
-our $VERSION = '0.60';
+our $VERSION = '0.61';
 
 sub new {
     my ($class, %args) = @_;
@@ -148,12 +148,13 @@ sub psgi {
             return $res->finalize;
         }
 
-        if ($self->api_format && (my $type = $req->accept_format)) {
-            if ($type ne $self->api_format) {
-                $self->log(error => 'Invalid accept header');
-                $res->render_error(406, 'Invalid accept header');
-                return $res->finalize;
-            }
+        my $type = $req->accept_format;
+        if (   ($req->header('Accept') && !$type)
+            || (($self->api_format && $type) && ($self->api_format ne $type)))
+        {
+            $self->log(error => 'Content-type provided not acceptable');
+            $res->render_error(406, 'Not acceptable');
+            return $res->finalize;
         }
 
         my $code = $route->code;
@@ -197,7 +198,8 @@ sub psgi {
         my $e = longmess($@);
         $self->log(error => $e);
 
-        my $msg = $ENV{PLACK_ENV} eq 'deployment' ? 'Internal error' : $e;
+        my $msg = $ENV{PLACK_ENV}
+            && $ENV{PLACK_ENV} eq 'deployment' ? 'Internal error' : $e;
         $res->render_500($msg);
     };
 
@@ -1044,8 +1046,6 @@ Shows an example of complex application.
 
 =over
 
-=item * C<param> doesn't work as expected;
-
 =item * Support for hypermedia (L<HAL|http://stateless.co/hal_specification.html>, L<Link headers|http://www.w3.org/wiki/LinkHeader>);
 
 =item * Versioning support;
